@@ -231,9 +231,14 @@ def buildHttpResponse(additionalResponseHeaders, controllerResponseBody, status,
 def addToKwargs(key, givenClass, valuesAsDictionary, kwargs):
     if ObjectHelper.isNotEmpty(givenClass):
         toClass = givenClass if ObjectHelper.isNotList(givenClass) else givenClass[0]
-        kwargs[key] = Serializer.convertFromJsonToObject({k:v for k,v in valuesAsDictionary.items()}, toClass)
+        kwargs[key] = Serializer.convertFromJsonToObject({k:getKwargsAttributeValue(k, v) for k,v in valuesAsDictionary.items()}, toClass)
     return valuesAsDictionary
 
+def getKwargsAttributeValue(key, value):
+    if key.endswith(Serializer.LIST_SUFIX) and ObjectHelper.isNotList(value):
+        return [value]
+    return value
+
 @Function
 def getGlobals():
     return globals.getGlobalsInstance()
